
<h4 align="center">

[![PyPI Downloads](https://img.shields.io/pypi/dm/NepTrainKit?logo=pypi&logoColor=white&color=blue&label=PyPI)](https://pypi.org/project/NepTrainKit)
[![Requires Python 3.10+](https://img.shields.io/badge/Python-3.10+-blue.svg?logo=python&logoColor=white)](https://python.org/downloads)
[![codecov](https://codecov.io/github/aboys-cb/NepTrainKit/graph/badge.svg?token=HQ5FMLD91F)](https://codecov.io/github/aboys-cb/NepTrainKit)
</h4>




#  About NepTrainKit
NepTrainKit is a toolkit focused on the operation and visualization of neuroevolution potential(NEP) training datasets. It is mainly used to simplify and optimize the NEP model training process, providing an intuitive graphical interface and analysis tools to help users adjust  train dataset.
# Community Support

- Join the community chat (https://qm.qq.com/q/wPDQYHMhyg)
- Raise issues and engage in discussions via GitHub issues



# Installation

**It is strongly recommended to use pip for installation.**

## Installation Methods
### 1. Install via pip

If you are using Python 3.10 or a later version, you can install NepTrainKit using an environment manager like `conda`:
1. Create a new environment:
   ```bash
   conda create -n nepkit python=3.10
   ```
2. Activate the environment:
   ```bash
   conda activate nepkit
   ```
3. For CentOS users, install PySide6 (required for GUI functionality):
   ```bash
   conda install -c conda-forge pyside6
- Install directly using the `pip install` command:
  ```bash
  pip install NepTrainKit
  ```
  After installation, you can call the program using either `NepTrainKit` or `nepkit`.

- For the **latest version** (from GitHub):
  ```bash
  pip install git+https://github.com/aboys-cb/NepTrainKit.git
  ```

### 2. Download Executable (Windows Only)
- Visit the **release** page of this project to download the executable **NepTrainKit.win32.zip**. Note that this executable currently only supports Windows systems.

 
 ## Documentation and Examples
For detailed usage documentation and examples, please refer to the official documentation:  
[https://neptrainkit.readthedocs.io/en/latest/index.html](https://neptrainkit.readthedocs.io/en/latest/index.html)